@@ -1,23 +1,24 @@
 
 #define PACKAGE_NAME "am-utils"
 #define PACKAGE_TARNAME "am-utils"
-#define PACKAGE_VERSION "6.1b3-pre"
-#define PACKAGE_STRING "am-utils 6.1b3-pre"
-#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
+#define PACKAGE_VERSION "6.2a1"
+#define PACKAGE_STRING "am-utils 6.2a1"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define HOST_CPU "i386"
 #define HOST_VENDOR "unknown"
-#define HOST_OS "netbsdelf1.6.1"
-#define HOST_OS_NAME "netbsdelf1"
-#define HOST_OS_VERSION "1.6.1"
+#define HOST_OS "netbsd1.6.2"
+#define HOST_OS_NAME "netbsd"
+#define HOST_OS_VERSION "1.6.2"
 #define HOST_ARCH "i386"
-#define HOST_NAME "a-netbsd161"
+#define DISTRO_NAME "none"
+#define HOST_NAME "a-netbsd162.fsl.cs.sunysb.edu"
 #define USER_NAME "ezk"
-#define CONFIG_DATE "Sat Aug  2 13:46:54 EDT 2003"
+#define CONFIG_DATE "Fri Oct  7 17:14:43 EDT 2005"
 #define PACKAGE_NAME "am-utils"
-#define PACKAGE_VERSION "6.1b3-pre"
-#define PACKAGE_BUGREPORT "amd-dev@am-utils.org"
+#define PACKAGE_VERSION "6.2a1"
+#define PACKAGE_BUGREPORT "https://bugzilla.am-utils.org/ or am-utils@am-utils.org"
 #define PACKAGE "am-utils"
-#define VERSION "6.1b3-pre"
+#define VERSION "6.2a1"
 #define DEBUG 1
 #define STDC_HEADERS 1
 #define HAVE_SYS_TYPES_H 1
@@ -30,10 +31,9 @@
 #define HAVE_STDINT_H 1
 #define HAVE_UNISTD_H 1
 #define HAVE_DLFCN_H 1
-#define HOST_HEADER_VERSION "1.6.1"
+#define HOST_HEADER_VERSION "1.6.2"
 #define YYTEXT_POINTER 1
 #define HAVE_LIBRPCSVC 1
-#define HAVE_ALLOCA 1
 #define HAVE_UNISTD_H 1
 #define HAVE_FORK 1
 #define HAVE_VFORK 1
@@ -59,9 +59,8 @@
 #define HAVE_GETMNTINFO 1
 #define HAVE_GETPAGESIZE 1
 #define HAVE_GETTIMEOFDAY 1
-#define HAVE_HES_INIT 1
-#define HAVE_HESIOD_INIT 1
-#define HAVE_HESIOD_TO_BIND 1
+#define HAVE_HSTRERROR 1
+#define HAVE_MADVISE 1
 #define HAVE_MEMCMP 1
 #define HAVE_MEMCPY 1
 #define HAVE_MEMMOVE 1
@@ -79,12 +78,16 @@
 #define HAVE_SETSID 1
 #define HAVE_SIGACTION 1
 #define HAVE_SIGNAL 1
+#define HAVE_SIGSUSPEND 1
 #define HAVE_SOCKET 1
+#define HAVE_STATFS 1
+#define HAVE_STRCASECMP 1
 #define HAVE_STRCHR 1
 #define HAVE_STRCSPN 1
-#define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCAT 1
+#define HAVE_STRLCPY 1
 #define HAVE_STRSPN 1
 #define HAVE_STRSTR 1
 #define HAVE_SVC_GETREQ 1
@@ -96,10 +99,15 @@
 #define HAVE_VSNPRINTF 1
 #define HAVE_WAIT3 1
 #define HAVE_WAITPID 1
+#define HAVE_HES_INIT 1
+#define HAVE_HESIOD_INIT 1
+#define HAVE_HESIOD_TO_BIND 1
 #define HAVE_CLNT_SPERRNO 1
 #define HAVE_STRCASECMP 1
 #define HAVE_STRDUP 1
 #define HAVE_STRERROR 1
+#define HAVE_STRLCAT 1
+#define HAVE_STRLCPY 1
 #define HAVE_STRSTR 1
 #define HAVE_UALARM 1
 #define HAVE_XDR_ATTRSTAT 1
@@ -198,8 +206,8 @@
 #define HAVE_FCNTL_H 1
 #define HAVE_IFADDRS_H 1
 #define HAVE_GRP_H 1
-#define HAVE_HESIOD_H 1
 #define HAVE_LIBGEN_H 1
+#define HAVE_LIMITS_H 1
 #define HAVE_MALLOC_H 1
 #define HAVE_MEMORY_H 1
 #define HAVE_NDBM_H 1
@@ -221,13 +229,14 @@
 #define HAVE_TIME_H 1
 #define HAVE_VARARGS_H 1
 #define HAVE_UNISTD_H 1
+#define HAVE_HESIOD_H 1
 #define TIME_WITH_SYS_TIME 1
 #define AMU_NFS_PROTOCOL_HEADER "../conf/nfs_prot/nfs_prot_netbsd1_4.h"
 #define HAVE_STRUCT_NFS_ARGS 1
 #define nfs_args_t struct nfs_args
 #define NFS_FH_FIELD fh
 #define am_nfs_fh nfs_fh
-#define am_nfs_fh3 nfs_fh3
+#define HAVE_FS_NFS3 1
 #define GETGROUPS_T gid_t
 #define RETSIGTYPE void
 #define HAVE_FHANDLE 1
@@ -243,6 +252,7 @@
 #define ufs_args_t struct ufs_args
 #define XDRPROC_T_TYPE xdrproc_t
 #define voidp void *
+#define HAVE_C99_VARARGS_MACROS 1
 #define HAVE_EXTERN_SYS_ERRLIST 1
 #define HAVE_EXTERN_OPTARG 1
 #define HAVE_EXTERN_CLNT_SPCREATEERROR 1
@@ -259,8 +269,11 @@
 #define HAVE_EXTERN_SBRK 1
 #define HAVE_EXTERN_SETEUID 1
 #define HAVE_EXTERN_SETITIMER 1
+#define HAVE_EXTERN_SLEEP 1
 #define HAVE_EXTERN_STRCASECMP 1
 #define HAVE_EXTERN_STRDUP 1
+#define HAVE_EXTERN_STRLCAT 1
+#define HAVE_EXTERN_STRLCPY 1
 #define HAVE_EXTERN_STRSTR 1
 #define HAVE_EXTERN_UALARM 1
 #define HAVE_EXTERN_USLEEP 1
@@ -271,6 +284,7 @@
 #define HAVE_LONG_FILE_NAMES 1
 #define HAVE_UNISTD_H 1
 #define HAVE_RESTARTABLE_SYSCALLS 1
+#define HAVE_FD_SET_FDS_BITS 1
 #define HAVE_CDFS_ARGS_T_FLAGS 1
 #define HAVE_CDFS_ARGS_T_FSPEC 1
 #define HAVE_PCFS_ARGS_T_FSPEC 1
@@ -287,6 +301,8 @@
 #define HAVE_STRUCT_IFADDRS_IFA_NEXT 1
 #define HAVE_STRUCT_SOCKADDR_SA_LEN 1
 #define HAVE_MAP_FILE 1
+#define HAVE_MAP_SUN 1
+#define HAVE_MAP_EXEC 1
 #define HAVE_MAP_HESIOD 1
 #define HAVE_MAP_NIS 1
 #define HAVE_MAP_PASSWD 1
@@ -294,7 +310,6 @@
 #define HAVE_FS_CDFS 1
 #define HAVE_FS_MFS 1
 #define HAVE_FS_NFS 1
-#define HAVE_FS_NFS3 1
 #define HAVE_FS_PCFS 1
 #define HAVE_FS_UFS 1
 #define HAVE_FS_NULLFS 1
@@ -304,7 +319,6 @@
 #define HAVE_AMU_FS_DIRECT 1
 #define HAVE_AMU_FS_TOPLVL 1
 #define HAVE_AMU_FS_ERROR 1
-#define HAVE_AMU_FS_INHERIT 1
 #define HAVE_AMU_FS_PROGRAM 1
 #define HAVE_AMU_FS_LINK 1
 #define HAVE_AMU_FS_LINKX 1
@@ -334,6 +348,7 @@
 #define MNTTAB_TYPE_UNIONFS "unionfs"
 #define MNTTAB_TYPE_UMAPFS "umapfs"
 #define MNT2_GEN_OPT_ASYNC 0x40
+#define MNT2_GEN_OPT_FORCE 0x80000
 #define MNT2_GEN_OPT_IGNORE 0x100000
 #define MNT2_GEN_OPT_NODEV 0x10
 #define MNT2_GEN_OPT_NOEXEC 0x4
